==> mxv-v1.07-source.tar.gz: rescaler.h <==
// rescaler.h

/******************************************************************************
 *
 *  MiXViews - an X window system based sound & data editor/processor
 *
 *  Copyright (c) 1993, 1994 Regents of the University of California
 *
 *  Author:     Douglas Scott
 *  Date:       December 13, 1994
 *
 *  Permission to use, copy and modify this software and its documentation
 *  for research and/or educational purposes and without fee is hereby granted,
 *  provided that the above copyright notice appear in all copies and that
 *  both that copyright notice and this permission notice appear in
 *  supporting documentation. The author reserves the right to distribute this
 *  software and its documentation.  The University of California and the author
 *  make no representations about the suitability of this software for any 
 *  purpose, and in no event shall University of California be liable for any
 *  damage, loss of data, or profits resulting from its use.
 *  It is provided "as is" without express or implied warranty.
 *
 ******************************************************************************/


// Rescalers modify data values to fit into an arbitrary range.

#ifndef RESCALER_H
#ifdef __GNUG__
#pragma interface
#endif
#define RESCALER_H

#include "datamodifier.h"
#include "range.h"

class Rescaler : public DataModifier {
	typedef DataModifier Super;
public:
	Rescaler(Data* d, const Range&);
	Rescaler(Data* d);
	static Modifier* create(class DataEditor*);
	redefined const char* message() { return "Rescaling..."; }
	redefined Modifier* createUnDo();
protected:
	redefined void configureRequest(Request &r);
	redefined boolean setValues(Request& r);
	redefined int doApply(Data *);
private:
	redefined const QueryInfo *requestInfo();
	Range oldRange;
	Range newRange;
	boolean preserveZero;
};

#endif

==> mxv-v1.10-source.tar.gz: rescaler.h <==
// rescaler.h

/******************************************************************************
 *
 *  MiXViews - an X window system based sound & data editor/processor
 *
 *  Copyright (c) 1993, 1994 Regents of the University of California
 *
 *  Author:     Douglas Scott
 *  Date:       December 13, 1994
 *
 *  Permission to use, copy and modify this software and its documentation
 *  for research and/or educational purposes and without fee is hereby granted,
 *  provided that the above copyright notice appear in all copies and that
 *  both that copyright notice and this permission notice appear in
 *  supporting documentation. The author reserves the right to distribute this
 *  software and its documentation.  The University of California and the author
 *  make no representations about the suitability of this software for any 
 *  purpose, and in no event shall University of California be liable for any
 *  damage, loss of data, or profits resulting from its use.
 *  It is provided "as is" without express or implied warranty.
 *
 ******************************************************************************/


// Rescalers modify data values to fit into an arbitrary range.

#ifndef RESCALER_H
#ifdef __GNUG__
#pragma interface
#endif
#define RESCALER_H

#include "datamodifier.h"
#include "range.h"

class Requester;

class Rescaler : public DataModifier {
	typedef DataModifier Super;
	friend class RescaleRequester;
public:
	Rescaler(Data* d, const Range&);
	Rescaler(Data* d);
	static Modifier* create(class DataEditor*);
	redefined const char* message() { return "Rescaling..."; }
	redefined Modifier* createUnDo();
protected:
	redefined Requester* createRequester();
	redefined void initialize();
	redefined int doApply(Data *);
private:
	QueryRange oldRange;
	QueryRange newRange;
	ChoiceValue preserveZero;
};

#endif
